<?php
use \Psr\Http\Message\ServerRequestInterface as Request;
use \Psr\Http\Message\ResponseInterface as Response;

require '../../vendor/autoload.php';
require '/config/db.php';

$app = new \Slim\App;

function processMethod($pSql) {
	try {
		$db = new db();
		$db = $db->connect();
		$stmt = $db->prepare($pSql);
		$success = $stmt->execute();
		if ($success) {
			$rows = $stmt->fetchAll(PDO::FETCH_ASSOC);
			echo json_encode($rows);
		}
		$db = null;
	} catch(PDOException $e) {
		echo '[{"Error_Text": "'.$e->getMessage().'"}]';
	}
}

/* Method 1: List */
$app->get('/Admines', function (Request $request, Response $response) {
	$sql = "CALL CB.pCB_ListAdmines();";
	processMethod($sql);
});

/* Method 2: Show */
$app->get('/Admines/{pAdmin_Id}', function (Request $request, Response $response) {
	$pAdmin_Id = $request->getAttribute('pAdmin_Id');
	$sql = "CALL CB.pCB_ShowAdmin($pAdmin_Id);";
	processMethod($sql);
});

/* Method 3: Save */
$app->post('/Admines/{pAdmin_Id}&{pAdmin_Nombre}&{pAdmin_Usuario}&{pAdmin_Clave}&{pAdmin_Correo}&{pAdmin_Telefono}&{pAdmin_FechaCreacion}&{pAdmin_FlagVigencia}', function (Request $request, Response $response) {
	$pAdmin_Id = $request->getAttribute('pAdmin_Id');
	$pAdmin_Nombre = ($request->getAttribute('pAdmin_Nombre')=='null' ? $request->getAttribute('pAdmin_Nombre') : "'" + $request->getAttribute('pAdmin_Nombre') + "'");
	$pAdmin_Usuario = ($request->getAttribute('pAdmin_Usuario')=='null' ? $request->getAttribute('pAdmin_Usuario') : "'" + $request->getAttribute('pAdmin_Usuario') + "'");
	$pAdmin_Clave = ($request->getAttribute('pAdmin_Clave')=='null' ? $request->getAttribute('pAdmin_Clave') : "'" + $request->getAttribute('pAdmin_Clave') + "'");
	$pAdmin_Correo = ($request->getAttribute('pAdmin_Correo')=='null' ? $request->getAttribute('pAdmin_Correo') : "'" + $request->getAttribute('pAdmin_Correo') + "'");
	$pAdmin_Telefono = ($request->getAttribute('pAdmin_Telefono')=='null' ? $request->getAttribute('pAdmin_Telefono') : "'" + $request->getAttribute('pAdmin_Telefono') + "'");
	$pAdmin_FechaCreacion = ($request->getAttribute('pAdmin_FechaCreacion')=='null' ? $request->getAttribute('pAdmin_FechaCreacion') : "'" + $request->getAttribute('pAdmin_FechaCreacion') + "'");
	$pAdmin_FlagVigencia = $request->getAttribute('pAdmin_FlagVigencia');
	$sql = "CALL CB.pCB_SaveAdmin($pAdmin_Id, $pAdmin_Nombre, $pAdmin_Usuario, $pAdmin_Clave, $pAdmin_Correo, $pAdmin_Telefono, $pAdmin_FechaCreacion, $pAdmin_FlagVigencia);";
	processMethod($sql);
});

/* Method 4: Delete */
$app->post('/Admines/{pAdmin_Id}', function (Request $request, Response $response) {
	$pAdmin_Id = $request->getAttribute('Admin_Id');
	$sql = "CALL CB.pCB_DeleteAdmin($pAdmin_Id)";
	processMethod($sql);
});

/* Method 1: List */
$app->get('/Clientes', function (Request $request, Response $response) {
	$sql = "CALL CB.pCB_ListClientes();";
	processMethod($sql);
});

/* Method 2: Show */
$app->get('/Clientes/{pCliente_Id}', function (Request $request, Response $response) {
	$pCliente_Id = $request->getAttribute('pCliente_Id');
	$sql = "CALL CB.pCB_ShowCliente($pCliente_Id);";
	processMethod($sql);
});

/* Method 3: Save */
$app->post('/Clientes/{pCliente_Id}&{pCliente_Rut}&{pCliente_Nombre}&{pCliente_Usuario}&{pCliente_Clave}&{pCliente_Telefono}&{pCliente_Direccion}&{pCliente_Sexo}&{pCliente_FechaNacimiento}&{pCliente_FlagVigencia}', function (Request $request, Response $response) {
	$pCliente_Id = $request->getAttribute('pCliente_Id');
	$pCliente_Rut = ($request->getAttribute('pCliente_Rut')=='null' ? $request->getAttribute('pCliente_Rut') : "'" + $request->getAttribute('pCliente_Rut') + "'");
	$pCliente_Nombre = ($request->getAttribute('pCliente_Nombre')=='null' ? $request->getAttribute('pCliente_Nombre') : "'" + $request->getAttribute('pCliente_Nombre') + "'");
	$pCliente_Usuario = ($request->getAttribute('pCliente_Usuario')=='null' ? $request->getAttribute('pCliente_Usuario') : "'" + $request->getAttribute('pCliente_Usuario') + "'");
	$pCliente_Clave = ($request->getAttribute('pCliente_Clave')=='null' ? $request->getAttribute('pCliente_Clave') : "'" + $request->getAttribute('pCliente_Clave') + "'");
	$pCliente_Telefono = ($request->getAttribute('pCliente_Telefono')=='null' ? $request->getAttribute('pCliente_Telefono') : "'" + $request->getAttribute('pCliente_Telefono') + "'");
	$pCliente_Direccion = ($request->getAttribute('pCliente_Direccion')=='null' ? $request->getAttribute('pCliente_Direccion') : "'" + $request->getAttribute('pCliente_Direccion') + "'");
	$pCliente_Sexo = ($request->getAttribute('pCliente_Sexo')=='null' ? $request->getAttribute('pCliente_Sexo') : "'" + $request->getAttribute('pCliente_Sexo') + "'");
	$pCliente_FechaNacimiento = ($request->getAttribute('pCliente_FechaNacimiento')=='null' ? $request->getAttribute('pCliente_FechaNacimiento') : "'" + $request->getAttribute('pCliente_FechaNacimiento') + "'");
	$pCliente_FlagVigencia = $request->getAttribute('pCliente_FlagVigencia');
	$sql = "CALL CB.pCB_SaveCliente($pCliente_Id, $pCliente_Rut, $pCliente_Nombre, $pCliente_Usuario, $pCliente_Clave, $pCliente_Telefono, $pCliente_Direccion, $pCliente_Sexo, $pCliente_FechaNacimiento, $pCliente_FlagVigencia);";
	processMethod($sql);
});

/* Method 4: Delete */
$app->post('/Clientes/{pCliente_Id}', function (Request $request, Response $response) {
	$pCliente_Id = $request->getAttribute('Cliente_Id');
	$sql = "CALL CB.pCB_DeleteCliente($pCliente_Id)";
	processMethod($sql);
});

/* Method 1: List */
$app->get('/Comercios', function (Request $request, Response $response) {
	$sql = "CALL CB.pCB_ListComercios();";
	processMethod($sql);
});

/* Method 2: Show */
$app->get('/Comercios/{pComercio_Id}', function (Request $request, Response $response) {
	$pComercio_Id = $request->getAttribute('pComercio_Id');
	$sql = "CALL CB.pCB_ShowComercio($pComercio_Id);";
	processMethod($sql);
});

/* Method 3: Save */
$app->post('/Comercios/{pComercio_Id}&{pComercio_Rut}&{pComercio_Nombre}&{pComercio_Giro}&{pComercio_Direccion}&{pComercio_Telefono}&{pComercio_Correo}&{pComercio_Descripcion}&{pComercio_URL}&{pComercio_ResponsableNombre}&{pComercio_ResponsableTelefono}&{pComercio_ResponsableCorreo}', function (Request $request, Response $response) {
	$pComercio_Id = $request->getAttribute('pComercio_Id');
	$pComercio_Rut = ($request->getAttribute('pComercio_Rut')=='null' ? $request->getAttribute('pComercio_Rut') : "'" + $request->getAttribute('pComercio_Rut') + "'");
	$pComercio_Nombre = ($request->getAttribute('pComercio_Nombre')=='null' ? $request->getAttribute('pComercio_Nombre') : "'" + $request->getAttribute('pComercio_Nombre') + "'");
	$pComercio_Giro = ($request->getAttribute('pComercio_Giro')=='null' ? $request->getAttribute('pComercio_Giro') : "'" + $request->getAttribute('pComercio_Giro') + "'");
	$pComercio_Direccion = ($request->getAttribute('pComercio_Direccion')=='null' ? $request->getAttribute('pComercio_Direccion') : "'" + $request->getAttribute('pComercio_Direccion') + "'");
	$pComercio_Telefono = ($request->getAttribute('pComercio_Telefono')=='null' ? $request->getAttribute('pComercio_Telefono') : "'" + $request->getAttribute('pComercio_Telefono') + "'");
	$pComercio_Correo = ($request->getAttribute('pComercio_Correo')=='null' ? $request->getAttribute('pComercio_Correo') : "'" + $request->getAttribute('pComercio_Correo') + "'");
	$pComercio_Descripcion = ($request->getAttribute('pComercio_Descripcion')=='null' ? $request->getAttribute('pComercio_Descripcion') : "'" + $request->getAttribute('pComercio_Descripcion') + "'");
	$pComercio_URL = ($request->getAttribute('pComercio_URL')=='null' ? $request->getAttribute('pComercio_URL') : "'" + $request->getAttribute('pComercio_URL') + "'");
	$pComercio_ResponsableNombre = ($request->getAttribute('pComercio_ResponsableNombre')=='null' ? $request->getAttribute('pComercio_ResponsableNombre') : "'" + $request->getAttribute('pComercio_ResponsableNombre') + "'");
	$pComercio_ResponsableTelefono = ($request->getAttribute('pComercio_ResponsableTelefono')=='null' ? $request->getAttribute('pComercio_ResponsableTelefono') : "'" + $request->getAttribute('pComercio_ResponsableTelefono') + "'");
	$pComercio_ResponsableCorreo = ($request->getAttribute('pComercio_ResponsableCorreo')=='null' ? $request->getAttribute('pComercio_ResponsableCorreo') : "'" + $request->getAttribute('pComercio_ResponsableCorreo') + "'");
	$sql = "CALL CB.pCB_SaveComercio($pComercio_Id, $pComercio_Rut, $pComercio_Nombre, $pComercio_Giro, $pComercio_Direccion, $pComercio_Telefono, $pComercio_Correo, $pComercio_Descripcion, $pComercio_URL, $pComercio_ResponsableNombre, $pComercio_ResponsableTelefono, $pComercio_ResponsableCorreo);";
	processMethod($sql);
});

/* Method 4: Delete */
$app->post('/Comercios/{pComercio_Id}', function (Request $request, Response $response) {
	$pComercio_Id = $request->getAttribute('Comercio_Id');
	$sql = "CALL CB.pCB_DeleteComercio($pComercio_Id)";
	processMethod($sql);
});

/* Method 1: List */
$app->get('/BeneficioClienteLocales', function (Request $request, Response $response) {
	$sql = "CALL CB.pCB_ListBeneficioClienteLocales();";
	processMethod($sql);
});

/* Method 2: Show */
$app->get('/BeneficioClienteLocales/{pBenCliLo_Id}', function (Request $request, Response $response) {
	$pBenCliLo_Id = $request->getAttribute('pBenCliLo_Id');
	$sql = "CALL CB.pCB_ShowBeneficioClienteLocal($pBenCliLo_Id);";
	processMethod($sql);
});

/* Method 3: Save */
$app->post('/BeneficioClienteLocales/{pBenCliLo_Id}&{pBeneficio_Id}&{pCliente_Id}&{pLocal_Id}', function (Request $request, Response $response) {
	$pBenCliLo_Id = $request->getAttribute('pBenCliLo_Id');
	$pBeneficio_Id = $request->getAttribute('pBeneficio_Id');
	$pCliente_Id = $request->getAttribute('pCliente_Id');
	$pLocal_Id = $request->getAttribute('pLocal_Id');
	$sql = "CALL CB.pCB_SaveBeneficioClienteLocal($pBenCliLo_Id, $pBeneficio_Id, $pCliente_Id, $pLocal_Id);";
	processMethod($sql);
});

/* Method 4: Delete */
$app->post('/BeneficioClienteLocales/{pBenCliLo_Id}', function (Request $request, Response $response) {
	$pBenCliLo_Id = $request->getAttribute('BenCliLo_Id');
	$sql = "CALL CB.pCB_DeleteBeneficioClienteLocal($pBenCliLo_Id)";
	processMethod($sql);
});

/* Method 1: List */
$app->get('/Locales', function (Request $request, Response $response) {
	$sql = "CALL CB.pCB_ListLocales();";
	processMethod($sql);
});

/* Method 2: Show */
$app->get('/Locales/{pLocal_Id}', function (Request $request, Response $response) {
	$pLocal_Id = $request->getAttribute('pLocal_Id');
	$sql = "CALL CB.pCB_ShowLocal($pLocal_Id);";
	processMethod($sql);
});

/* Method 3: Save */
$app->post('/Locales/{pLocal_Id}&{pLocal_Direccion}&{pLocal_Telefono}&{pComercio_Id}', function (Request $request, Response $response) {
	$pLocal_Id = $request->getAttribute('pLocal_Id');
	$pLocal_Direccion = ($request->getAttribute('pLocal_Direccion')=='null' ? $request->getAttribute('pLocal_Direccion') : "'" + $request->getAttribute('pLocal_Direccion') + "'");
	$pLocal_Telefono = ($request->getAttribute('pLocal_Telefono')=='null' ? $request->getAttribute('pLocal_Telefono') : "'" + $request->getAttribute('pLocal_Telefono') + "'");
	$pComercio_Id = $request->getAttribute('pComercio_Id');
	$sql = "CALL CB.pCB_SaveLocal($pLocal_Id, $pLocal_Direccion, $pLocal_Telefono, $pComercio_Id);";
	processMethod($sql);
});

/* Method 4: Delete */
$app->post('/Locales/{pLocal_Id}', function (Request $request, Response $response) {
	$pLocal_Id = $request->getAttribute('Local_Id');
	$sql = "CALL CB.pCB_DeleteLocal($pLocal_Id)";
	processMethod($sql);
});

/* Method 1: List */
$app->get('/Operadores', function (Request $request, Response $response) {
	$sql = "CALL CB.pCB_ListOperadores();";
	processMethod($sql);
});

/* Method 2: Show */
$app->get('/Operadores/{pOperador_Id}', function (Request $request, Response $response) {
	$pOperador_Id = $request->getAttribute('pOperador_Id');
	$sql = "CALL CB.pCB_ShowOperador($pOperador_Id);";
	processMethod($sql);
});

/* Method 3: Save */
$app->post('/Operadores/{pOperador_Id}&{pOperador_Rut}&{pOperador_Nombre}&{pOperador_Usuario}&{pOperador_Clave}&{pOperador_Telefono}&{pOperador_Direccion}&{pOperador_Sexo}&{pOperador_FechaNacimiento}&{pOperador_FlagVigecia}&{pComercio_Id}', function (Request $request, Response $response) {
	$pOperador_Id = $request->getAttribute('pOperador_Id');
	$pOperador_Rut = ($request->getAttribute('pOperador_Rut')=='null' ? $request->getAttribute('pOperador_Rut') : "'" + $request->getAttribute('pOperador_Rut') + "'");
	$pOperador_Nombre = ($request->getAttribute('pOperador_Nombre')=='null' ? $request->getAttribute('pOperador_Nombre') : "'" + $request->getAttribute('pOperador_Nombre') + "'");
	$pOperador_Usuario = ($request->getAttribute('pOperador_Usuario')=='null' ? $request->getAttribute('pOperador_Usuario') : "'" + $request->getAttribute('pOperador_Usuario') + "'");
	$pOperador_Clave = ($request->getAttribute('pOperador_Clave')=='null' ? $request->getAttribute('pOperador_Clave') : "'" + $request->getAttribute('pOperador_Clave') + "'");
	$pOperador_Telefono = ($request->getAttribute('pOperador_Telefono')=='null' ? $request->getAttribute('pOperador_Telefono') : "'" + $request->getAttribute('pOperador_Telefono') + "'");
	$pOperador_Direccion = ($request->getAttribute('pOperador_Direccion')=='null' ? $request->getAttribute('pOperador_Direccion') : "'" + $request->getAttribute('pOperador_Direccion') + "'");
	$pOperador_Sexo = ($request->getAttribute('pOperador_Sexo')=='null' ? $request->getAttribute('pOperador_Sexo') : "'" + $request->getAttribute('pOperador_Sexo') + "'");
	$pOperador_FechaNacimiento = ($request->getAttribute('pOperador_FechaNacimiento')=='null' ? $request->getAttribute('pOperador_FechaNacimiento') : "'" + $request->getAttribute('pOperador_FechaNacimiento') + "'");
	$pOperador_FlagVigecia = $request->getAttribute('pOperador_FlagVigecia');
	$pComercio_Id = $request->getAttribute('pComercio_Id');
	$sql = "CALL CB.pCB_SaveOperador($pOperador_Id, $pOperador_Rut, $pOperador_Nombre, $pOperador_Usuario, $pOperador_Clave, $pOperador_Telefono, $pOperador_Direccion, $pOperador_Sexo, $pOperador_FechaNacimiento, $pOperador_FlagVigecia, $pComercio_Id);";
	processMethod($sql);
});

/* Method 4: Delete */
$app->post('/Operadores/{pOperador_Id}', function (Request $request, Response $response) {
	$pOperador_Id = $request->getAttribute('Operador_Id');
	$sql = "CALL CB.pCB_DeleteOperador($pOperador_Id)";
	processMethod($sql);
});

/* Method 1: List */
$app->get('/Beneficios', function (Request $request, Response $response) {
	$sql = "CALL CB.pCB_ListBeneficios();";
	processMethod($sql);
});

/* Method 2: Show */
$app->get('/Beneficios/{pBeneficio_Id}', function (Request $request, Response $response) {
	$pBeneficio_Id = $request->getAttribute('pBeneficio_Id');
	$sql = "CALL CB.pCB_ShowBeneficio($pBeneficio_Id);";
	processMethod($sql);
});

/* Method 3: Save */
$app->post('/Beneficios/{pBeneficio_Id}&{pBeneficio_Titulo}&{pBeneficio_Descripcion}&{pBeneficio_FechaDesde}&{pBeneficio_DechaHasta}&{pBeneficio_Moneda}&{pBeneficio_Precio}&{pAdmin_Id}&{pComercio_Id}', function (Request $request, Response $response) {
	$pBeneficio_Id = $request->getAttribute('pBeneficio_Id');
	$pBeneficio_Titulo = ($request->getAttribute('pBeneficio_Titulo')=='null' ? $request->getAttribute('pBeneficio_Titulo') : "'" + $request->getAttribute('pBeneficio_Titulo') + "'");
	$pBeneficio_Descripcion = ($request->getAttribute('pBeneficio_Descripcion')=='null' ? $request->getAttribute('pBeneficio_Descripcion') : "'" + $request->getAttribute('pBeneficio_Descripcion') + "'");
	$pBeneficio_FechaDesde = ($request->getAttribute('pBeneficio_FechaDesde')=='null' ? $request->getAttribute('pBeneficio_FechaDesde') : "'" + $request->getAttribute('pBeneficio_FechaDesde') + "'");
	$pBeneficio_DechaHasta = ($request->getAttribute('pBeneficio_DechaHasta')=='null' ? $request->getAttribute('pBeneficio_DechaHasta') : "'" + $request->getAttribute('pBeneficio_DechaHasta') + "'");
	$pBeneficio_Moneda = ($request->getAttribute('pBeneficio_Moneda')=='null' ? $request->getAttribute('pBeneficio_Moneda') : "'" + $request->getAttribute('pBeneficio_Moneda') + "'");
	$pBeneficio_Precio = $request->getAttribute('pBeneficio_Precio');
	$pAdmin_Id = $request->getAttribute('pAdmin_Id');
	$pComercio_Id = $request->getAttribute('pComercio_Id');
	$sql = "CALL CB.pCB_SaveBeneficio($pBeneficio_Id, $pBeneficio_Titulo, $pBeneficio_Descripcion, $pBeneficio_FechaDesde, $pBeneficio_DechaHasta, $pBeneficio_Moneda, $pBeneficio_Precio, $pAdmin_Id, $pComercio_Id);";
	processMethod($sql);
});

/* Method 4: Delete */
$app->post('/Beneficios/{pBeneficio_Id}', function (Request $request, Response $response) {
	$pBeneficio_Id = $request->getAttribute('Beneficio_Id');
	$sql = "CALL CB.pCB_DeleteBeneficio($pBeneficio_Id)";
	processMethod($sql);
});

$app->run();
